/*
 * prom_init is guaranteed to be called first before any
 * other prom function Gets passed the argc, argv of 
 * the bootloader.
 *
 */
void prom_init();
/*
 * Gets called after initialization. Get passed the args the boot loader
 * got passed. Either store and parse or drop it
 *
 */
void prom_parse_arg(int argc, char **argv, char **envp);
/*
 * Get the ospartition notation - this should be a string 
 * prom_open understands
 */
char *prom_get_ospartition(void );
/*
 * Get the label in the arcboot conf to look for - if unknown
 * the kernel name to boot. This may be NULL in which case we try to find "Linux"
 */
char *prom_get_oslabel(void );
/*
 * Return the command line args passed on the prom. It might be derived from
 * the prom_inits argc/argv - maybe a copy etc ...
 *
 */
void prom_get_arg(long *argc, char ***argv);
/* 
 * Return osoptions from the proms environment
 */
char *prom_get_osoptions(void );

/* 
 * Gets called shortly after prom_init to intialize the malloc
 * subsystem based on the proms information about memory layout
 *
 */
void prom_init_malloc(unsigned long start, unsigned long length);
void prom_restart(void );
void prom_flush_all_caches(void );
/* 
 * prom_fatal prints out the message and should return to the proms command line
 * interactive if possible. Otherwise it might decide to issue a reset
 *
 */
void prom_fatal(const char *message, ...);
void prom_wait(const char *prompt);
void prom_return_interactive(void );
int prom_write(FILE stream, char *buf, unsigned long len, unsigned long *rlen);
int prom_read(FILE stream, char *buf, unsigned long len, unsigned long *rlen);
/*
 * Open may be used to open "partitions" passed in by name from the prom. It is the
 * proms abstraction layers responsibility to associate a file which associates to the
 * block device
 *
 */
int prom_open(char *name, int mode, FILE *stream);
int prom_close(FILE stream);
/*
 * Seek on the e.g. partition to a specific block indicated by a byte offset.
 *
 */
int prom_seek(FILE stream, long long position, int whence);

enum {
	O_RDONLY,
	O_RDWR,
};

enum {
	SEEK_SET,
	SEEK_CUR,
};
